<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package De Minimalist
 * @since De Minimalist 2.0
 */

get_header(); ?>

<div id="primary">
	<div id="content" role="main">

		<?php if ( have_posts() ) : ?>

			<?php /* Start the Loop */ ?>
			<?php while ( have_posts() ) : the_post(); ?>

				<?php
				if ( has_post_format( 'aside' ) ) : { ?>

				<?php $format_link = get_post_format_link('chat'); ?> 
				<a href="<?php echo $format_link  ?>" class="format-icon f-chat"> </a>

				<div class="title">
				<h2> <a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link to <?php the_title(); ?>"> <?php the_title(); ?> </a> </h2>
				</div>
				
				<div class="entry">
				<?php the_post_thumbnail(); ?>
				<?php the_content('Read the rest of this entry &raquo;'); ?>
				<div class="clear"></div>
				</div>


				<?php }
				elseif ( has_post_format( 'image' ) ) : { ?>

				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
				<header class="entry-header">
					<h1 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'de_minimalist' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h1>
				</header><!-- .entry-header -->

				<div class="entry-content">
					<?php the_post_thumbnail(); ?>
					<?php the_content( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'de_minimalist' ) ); ?>
				</div><!-- .entry-content -->

				<footer class="entry-meta">
					<?php de_minimalist_posted_on(); ?>
					<?php if ( comments_open() || ( '0' != get_comments_number() && ! comments_open() ) ) : ?>
					<span class="sep"> | </span>
					<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'de_minimalist' ), __( '1 Comment', 'de_minimalist' ), __( '% Comments', 'de_minimalist' ) ); ?></span>
					<?php endif; ?>

				</footer><!-- #entry-meta -->
				</article><!-- #post-<?php the_ID(); ?> -->


				<?php }	
				elseif ( has_post_format( 'gallery' ) ) : { ?>

				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
				<header class="entry-header">
					<h1 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'de_minimalist' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h1>

					<div class="entry-meta">
						<?php de_minimalist_posted_on(); ?>
					</div><!-- .entry-meta -->
				</header><!-- .entry-header -->

				<?php if ( is_search() ) : // Only display Excerpts for search pages ?>
				<div class="entry-summary">
					<?php the_post_thumbnail(); ?>
					<?php the_excerpt(); ?>
				</div><!-- .entry-summary -->
				<?php else : ?>
				<div class="entry-content">
					<?php if ( post_password_required() ) : ?>
						<?php the_content( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'de_minimalist' ) ); ?>

						<?php else : ?>
							<?php
								$images = get_children( array( 'post_parent' => $post->ID, 'post_type' => 'attachment', 'post_mime_type' => 'image', 'orderby' => 'menu_order', 'order' => 'ASC' ) );
								if ( $images ) :
									$total_images = count( $images );
									$image = array_shift( $images );
									$image_img_tag = wp_get_attachment_image( $image->ID, 'thumbnail' );
							?>

							<figure class="gallery-thumb">
								<a href="<?php the_permalink(); ?>"><?php echo $image_img_tag; ?></a>
							</figure><!-- .gallery-thumb -->

							<p><em><?php printf( _n( 'This gallery contains <a %1$s>%2$s photo</a>.', 'This gallery contains <a %1$s>%2$s photos</a>.', $total_images, 'de_minimalist' ),
							'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink to %s', 'de_minimalist' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"',
							number_format_i18n( $total_images )
							); ?></em></p>
						<?php endif; ?>
						<?php the_post_thumbnail(); ?>
						<?php the_excerpt(); ?>
					<?php endif; ?>
				</div><!-- .entry-content -->
				<?php endif; ?>

				<footer class="entry-meta">
					<?php if ( 'post' == get_post_type() ) : // Hide category and tag text for pages on Search ?>

						<?php realodix_tag(); ?>

						<?php
							/* translators: used between list items, there is a space after the comma */
							$categories_list = get_the_category_list( __( ', ', 'de_minimalist' ) );
							if ( $categories_list && de_minimalist_categorized_blog() ) :
						?>
						<span class="cat-links">
							<?php printf( __( 'Posted in %1$s', 'de_minimalist' ), $categories_list ); ?>
						</span>
						<span class="sep"> | </span>
						<?php endif; // End if categories ?>

					<?php endif; // End if 'post' == get_post_type() ?>

					<?php if ( comments_open() || ( '0' != get_comments_number() && ! comments_open() ) ) : ?>
					<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'de_minimalist' ), __( '1 Comment', 'de_minimalist' ), __( '% Comments', 'de_minimalist' ) ); ?></span>
					<span class="sep"> | </span>
					<?php endif; ?>


				</footer><!-- #entry-meta -->
				</article><!-- #post-<?php the_ID(); ?> -->

				<?php }
				else : { ?>

				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
				<header class="entry-header">
				<h1 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php printf( esc_attr__( 'Permalink to %s', 'de_minimalist' ), the_title_attribute( 'echo=0' ) ); ?>" rel="bookmark"><?php the_title(); ?></a></h1>

				<?php if ( 'post' == get_post_type() ) : ?>
					<div class="entry-meta">
						<?php de_minimalist_posted_on(); ?>
					</div><!-- .entry-meta -->
				<?php endif; ?>
				</header><!-- .entry-header -->

				<?php if ( is_search() ) : // Only display Excerpts for Search ?>
				<div class="entry-summary">
					<?php the_post_thumbnail(); ?>
					<?php the_excerpt(); ?>
				</div><!-- .entry-summary -->
				<?php else : ?>
				<div class="entry-content">
					<?php the_content( __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'de_minimalist' ) ); ?>
				</div><!-- .entry-content -->
				<?php endif; ?>

				<footer class="entry-meta">
					<?php if ( 'post' == get_post_type() ) : // Hide category and tag text for pages on Search ?>

						<?php realodix_tag(); ?>

						<?php
						/* translators: used between list items, there is a space after the comma */
						$categories_list = get_the_category_list( __( ', ', 'de_minimalist' ) );
						if ( $categories_list && de_minimalist_categorized_blog() ) :
						?>
						<span class="sep"> | </span>
						<span class="cat-links">
							<?php printf( __( 'Posted in %1$s', 'de_minimalist' ), $categories_list ); ?>
						</span>
						<?php endif; // End if categories ?>

					<?php endif; // End if 'post' == get_post_type() ?>

					<?php if ( comments_open() || ( '0' != get_comments_number() && ! comments_open() ) ) : ?>
					<span class="comments-link"><?php comments_popup_link( __( 'Leave a comment', 'de_minimalist' ), __( '1 Comment', 'de_minimalist' ), __( '% Comments', 'de_minimalist' ) ); ?></span>
					<span class="sep"> | </span>
					<?php endif; ?>


				</footer><!-- #entry-meta -->
				</article><!-- #post-<?php the_ID(); ?> -->
		<?php }	endif; ?>
			<?php endwhile; ?>

	<?php kriesi_pagination();?>

		<?php else : ?>

			<article id="post-0" class="post no-results not-found">
				<header class="entry-header">
					<h1 class="entry-title"><?php _e( 'Nothing Found', 'de_minimalist' ); ?></h1>
				</header><!-- .entry-header -->

				<div class="entry-content">
					<p><?php _e( 'It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', 'de_minimalist' ); ?></p>
					<?php get_search_form(); ?>
				</div><!-- .entry-content -->
			</article><!-- #post-0 -->

		<?php endif; ?>

	</div><!-- #content -->
	<?php get_sidebar(); ?>
</div><!-- #primary -->

<?php get_footer(); ?>